part of katana_module;

/// FormConfig for using link TextField List.
@immutable
class LinkListFormConfig extends FormConfig {
  const LinkListFormConfig({
    this.backgroundColor,
    this.color,
    this.minLength,
    this.maxLength,
    this.maxItems,
    this.keyboardType = TextInputType.url,
    this.titleLabel,
    this.urlLabel,
  });

  static const String _type = "linkList";

  final int? maxItems;

  final Color? backgroundColor;

  final Color? color;

  final TextInputType keyboardType;

  final int? minLength;

  final int? maxLength;

  final String? titleLabel;

  final String? urlLabel;

  static LinkListFormConfig? _fromMap(DynamicMap map) {
    return LinkListFormConfig(
      backgroundColor: map.getAsMap("backgroundColor").toColor(),
      color: map.getAsMap("color").toColor(),
      minLength: map.get<int?>("minLength", null),
      maxLength: map.get<int?>("maxLength", null),
      keyboardType: TextInputType.values.firstWhereOrNull((element) =>
              element.index ==
              map.get("keyboardType", TextInputType.url.index)) ??
          TextInputType.url,
      maxItems: map.get<int?>("maxItems", null),
      titleLabel: map.get<String?>("titleLabel", null),
      urlLabel: map.get<String?>("urlLabel", null),
    );
  }

  /// Convert the form config to [DynamicMap].
  @override
  DynamicMap toMap() {
    return <String, dynamic>{
      "type": _type,
      "backgroundColor": backgroundColor.toMap(),
      "color": color.toMap(),
      if (minLength != null) "minLength": minLength,
      if (maxLength != null) "maxLength": maxLength,
      if (maxItems != null) "maxItems": maxItems,
      "keyboardType": keyboardType.index,
      if (titleLabel.isNotEmpty) "titleLabel": titleLabel,
      if (urlLabel.isNotEmpty) "urlLabel": urlLabel,
    };
  }
}
